package edu.jhu.nlp.wikipedia;

import org.xml.sax.Attributes;
import org.xml.sax.helpers.DefaultHandler;

/**
 * 
 * A Wrapper class for the PageCallbackHandler
 * 
 * @author Jason Smith
 *
 */
public class SAXPageCallbackHandler extends DefaultHandler {

	private PageCallbackHandler pageHandler;
	private WikiPage currentPage;
	private String currentTag;
	
	private StringBuilder currentWikitext;
	private StringBuilder currentTitle;
	private StringBuilder currentID;
	private StringBuilder currentNS;
	private StringBuilder currentRevID;
	private StringBuilder currentRevParentID;
	private StringBuilder currentRevTimestamp;
	private StringBuilder currentHashSHA1;
	private boolean currentMinor;
	
	public SAXPageCallbackHandler(PageCallbackHandler ph){
		pageHandler = ph;
	}
	
	public void startElement(String uri, String name, String qName, Attributes attr){
		currentTag = qName;
		if (qName.equals("page")){
			currentPage = new WikiPage();
			currentWikitext = new StringBuilder("");
			currentTitle = new StringBuilder("");
			currentID = new StringBuilder("");
			currentNS = new StringBuilder("");
			currentRevID = new StringBuilder("");
			currentRevParentID = new StringBuilder("");
			currentRevTimestamp = new StringBuilder("");
			currentHashSHA1 = new StringBuilder("");
			currentMinor = false;
		}
	}
	
	public void endElement(String uri, String name, String qName){
		if (qName.equals("page")){
			currentPage.setTitle(currentTitle.toString().trim());
			currentPage.setNS(currentNS.toString().trim());
			currentPage.setID(currentID.toString().trim());
			currentPage.setWikiText(currentWikitext.toString().trim());

			currentPage.setRevID(currentRevID.toString().trim());
			currentPage.setRevParentID(currentRevParentID.toString().trim());
			currentPage.setRevTimestamp(currentRevTimestamp.toString().trim());
			currentPage.setHashSHA1(currentHashSHA1.toString().trim());
			currentPage.setMinor(currentMinor);
			
			pageHandler.process(currentPage);
		}
//		if(qName.equals("timestamp")) {
//			currentPage.setRevTimestamp(currentRevTimestamp.toString());
//			System.out.println(currentRevTimestamp.toString());
//		}
//		if(qName.equals("ns")){
//			currentPage.setNS(currentNS.toString());
//			pageHandler.process(currentPage);
//		}
//		if (qName.equals("mediawiki"))
//		{
//			// TODO hasMoreElements() should now return false
//		}
		
	}
	
	// TODO: for what??
	public void characters(char ch[], int start, int length){
		if (currentTag.equals("title")){
			currentTitle = currentTitle.append(ch, start, length);
		}
		// TODO: To avoid looking at the revision ID, only the first ID is taken.
		// I'm not sure how big the block size is in each call to characters(),
		// so this may be unsafe.
		else if ((currentTag.equals("id")) && (currentID.length() == 0)){
			currentID = new StringBuilder();
			currentID.append(ch, start, length);
		}
		else if (currentTag.equals("text")){
			currentWikitext = currentWikitext.append(ch, start, length);
		}
		// TODO: find out, why we need this method...
		else if(currentTag.equals("ns")) {
			currentNS = currentNS.append(ch, start, length);
		}
		// TODO: problem ID given for page and revision (dinstinction??)
		else if(currentTag.equals("revID")) { // id??
			currentRevID = currentRevID.append(ch, start, length);
		}
		else if(currentTag.equals("parentid")) {
			currentRevParentID = currentRevParentID.append(ch, start, length);
		}
		else if(currentTag.equals("timestamp")) {
			currentRevTimestamp = currentRevTimestamp.append(ch, start, length);
		}
		else if(currentTag.equals("sha1")) {
			currentHashSHA1 = currentHashSHA1.append(ch, start, length);
		}
		else if(currentTag.equals("minor")) {
			currentMinor = true;
		}
	}
}
